@@ -5,7 +5,7 @@ use EV ();
 use XSLoader ();
 our $VERSION;
 BEGIN {
-    $VERSION = '0.16';
+    $VERSION = '0.17';
     XSLoader::load(__PACKAGE__, $VERSION);
 }
 use constant { WS_FRAGMENTED_EOF => 0, WS_FRAGMENTED_ERROR => -1, WS_FRAGMENTED_DATA => 1 };
@@ -14,8 +14,8 @@ our @EXPORT = qw/WS_FRAGMENTED_EOF WS_FRAGMENTED_ERROR WS_FRAGMENTED_NODATA/;
 
 sub new {
     my (undef, $self) = @_;
-    $self->{buffering} //= 1;
-    $self->{type} //= 'server';
+    $self->{buffering} = 1 unless defined $self->{buffering};
+    $self->{type} = 'server' unless defined $self->{type};
     _wslay_event_context_init($self, ($self->{fd} // fileno($self->{fh})), int($self->{type} eq 'server'));
     _wslay_event_config_set_no_buffering($self, int(!$self->{buffering}));
     _wslay_event_config_set_max_recv_msg_length($self, $self->{max_recv_size}) if defined $self->{max_recv_size};
